% A linear formulation for computing disk conformal mapping of simply-connected open triangle meshes
%
% Main program: 
% map = lineardiskmap(v,f)
%
% Input:
% v: nv x 3 vertex coordinates of a simply-connected open triangle mesh
% f: nf x 3 triangulations of a simply-connected open triangle mesh
%
% Output:
% map: nv x 2 vertex coordinates of the disk conformal parameterization
% 
% If you use this code in your own work, please cite the following paper:
% [1] G. P.-T. Choi and L. M. Lui, 
%     "A Linear Formulation for Disk Conformal Parameterization of Simply-Connected Open Surfaces."
%     Advances in Computational Mathematics, 44(1), pp. 87-114, 2018.
% 
% Copyright (c) 2015-2019, Gary Pui-Tung Choi
% https://scholar.harvard.edu/choi

addpath('data')
addpath('mfile')

%% Example 1: Chinese Lion

load('lion.mat');

% If you want to color your own mesh with curvature, please also run the following lines:
% FV.vertices = v;
% FV.faces = f;
% mean_curv_ori = patchcurvature(FV);
% mean_curv = mean_curv_ori;
% mean_curv(mean_curv_ori > mean(mean_curv_ori)+1*std(mean_curv_ori)) =  mean(mean_curv_ori)+1*std(mean_curv_ori);
% mean_curv(mean_curv_ori < mean(mean_curv_ori)-1*std(mean_curv_ori)) =  mean(mean_curv_ori)-1*std(mean_curv_ori);

% If you wish to view the meshes without texture, please use the following:
% plot_mesh(v',f');

plot_mesh(v',f',mean_curv); view([0 90]);
title('Input Mesh')
tic;
map = lineardiskmap(v,f);
toc
plot_mesh(map',f',mean_curv); view([-130 90]);
title('Linear Disk Conformal Parameterization of the Input Mesh')

%% Example 2: Bunny

load('bunny.mat')

plot_mesh(v',f',mean_curv); view([0 90]);
title('Input Mesh')

tic;
map = lineardiskmap(v,f);
toc

plot_mesh(map',f',mean_curv); view([180 90]);
title('Linear Disk Conformal Parameterization of the Input Mesh')

%% Example 3: Hand

load('hand.mat')

plot_mesh(v',f',mean_curv); view([40 70]);
title('Input Mesh')

tic;
map = lineardiskmap(v,f);
toc

plot_mesh(map',f',mean_curv); view([0 90]);
title('Linear Disk Conformal Parameterization of the Input Mesh')
