function [map,map_mu] = lbs(v,f,mu,landmark,target)

% -------------------------------------------------------
% Linear Beltrami Solver with given boundary constraints
% -------------------------------------------------------
% Input : 
% 	v - vertex (3xn)
% 	f - connection (3xm)
% 	mu - Beltrami coefficient (mx1 complex)
% 	Landmark - landmark point (vertex index, nx1)
% 	Target - target location ((x,y) coordinate, nx2)
%
% Output :
% 	map - the mapping result
% -------------------------------------------------------
% Remarks on landmark and target
%
%   Please includes the boundary constraints into the
%   input "landmark" and "target"
% -------------------------------------------------------
% Example :
%   load('test(lbs).mat');
%   mu = bc_metric(v,f,map,2);
%   bdy = freeBoundary(TriRep(f',v'));
%   landmark = bdy(:,1); 
%   target = [map(1,landmark)',map(2,landmark)'];
%   map_reconst = lbs(v,f,mu,landmark,target);
% -------------------------------------------------------

targetc = target(:,1) + 1i*target(:,2);
A = generalized_laplacian2D(v,f,mu);
b = -A(:,landmark)*targetc;
b(landmark) = targetc;
A(landmark,:) = 0; A(:,landmark) = 0;
%A(landmark,landmark) = diag(ones(length(landmark),1));
A = A + sparse(landmark,landmark,ones(length(landmark),1), size(A,1), size(A,2));
map = A\b;
map = [real(map)';imag(map)';1+0*map'];
map_mu = bc_metric(v,f,map,2);

end