function S = mesh2tri(v,f,bigtri,M)

%% Build up Laplacian matrix 

numofv = size(v,1); 
if nargin < 4
    if exist('laplace_beltrami','file') == 3
         M = laplace_beltrami(f,v,'Polthier');
    else M = laplacebeltrami(v',f');
    end
end


p1 = f(bigtri,1);
p2 = f(bigtri,2);
p3 = f(bigtri,3);

fixed = [p1,p2,p3];
[mrow,mcol,mval] = find(M(fixed,:));
M = M - sparse(fixed(mrow),mcol,mval,numofv, numofv) + ...
        sparse(fixed,fixed,[1,1,1],numofv, numofv);

%% Set boundary condition for big triangle

x1 = 0; y1 = 0; x2 = 100; y2 = 0;

a = v(p2,1:3) - v(p1,1:3);
b = v(p3,1:3) - v(p1,1:3);
sin1 = (norm(cross(a,b),2))/(norm(a,2)*norm(b,2));
ori_h = norm(b,2)*sin1;
ratio = norm([x1-x2,y1-y2],2)/norm(a,2);
y3 = ori_h*ratio;

x3 = sqrt(norm(b,2)^2*ratio^2-y3^2);

%% Solve matrix equation

c = zeros(numofv,1); c(p1) = x1; c(p2) = x2; c(p3) = x3;
d = zeros(numofv,1); d(p1) = y1; d(p2) = y2; d(p3) = y3;

z = M \ complex(c,d);
z = z-mean(z);
S = [2*real(z)./(1+abs(z).^2), 2*imag(z)./(1+abs(z).^2), (-1+abs(z).^2)./(1+abs(z).^2)];

%% Find optimal big triangle size
% Reason: the distribution will be the best 
% if the southmost triangle has similar size of the northmost one 

w = complex(S(:,1)./(1+S(:,3)), S(:,2)./(1+S(:,3)));

[~, index] = sort(abs(z(f(:,1)))+abs(z(f(:,2)))+abs(z(f(:,3))));
inner = index(1);
if inner == bigtri
    inner = index(2);
end

NorthTriSide = (abs(z(f(bigtri,1))-z(f(bigtri,2))) + ...
    abs(z(f(bigtri,2))-z(f(bigtri,3))) + ...
    abs(z(f(bigtri,3))-z(f(bigtri,1))))/3;

SouthTriSide = (abs(w(f(inner,1))-w(f(inner,2))) + ...
    abs(w(f(inner,2))-w(f(inner,3))) + ...
    abs(w(f(inner,3))-w(f(inner,1))))/3;

z = z*(sqrt(NorthTriSide*SouthTriSide))/(NorthTriSide);

S = [2*real(z)./(1+abs(z).^2), -2*imag(z)./(1+abs(z).^2), (-1+abs(z).^2)./(1+abs(z).^2)];