function vmap = spherical_tutte_map(f, bigtri)

% f: nx3 matrix

%% Compute spherical map by solving laplace equation on big triangle
if nargin <2
    bigtri = 1;
end
numofv = max(max(f)); 
W = compute_adjacency_matrix(f)/2; 
M = W + sparse(1:numofv,1:numofv,-diag(W)-(sum(W)'), numofv, numofv);

boundary = f(bigtri,1:3);
[mrow,mcol,mval] = find(M(boundary,:));
M = M - sparse(boundary(mrow), mcol, mval, numofv, numofv) + ...
        sparse(boundary, boundary, [1,1,1], numofv, numofv);
    
b = zeros(numofv,1);
b(boundary) = exp(1i*(2*pi*(0:2)/length(boundary)));

z = M \ b;
z = z-mean(z);
S = [2*real(z)./(1+abs(z).^2), 2*imag(z)./(1+abs(z).^2), (-1+abs(z).^2)./(1+abs(z).^2)];

%% Find optimal big triangle size
% Reason: the distribution will be the best 
% if the southmost triangle has similar size of the northmost one 

w = complex(S(:,1)./(1+S(:,3)), S(:,2)./(1+S(:,3)));

% find the index of the southernmost triangle
[~, index] = sort(abs(z(f(:,1)))+abs(z(f(:,2)))+abs(z(f(:,3))));
inner = index(1);
if inner == bigtri
    inner = index(2);
end

NorthTriSide = (abs(z(f(bigtri,1))-z(f(bigtri,2))) + ...
    abs(z(f(bigtri,2))-z(f(bigtri,3))) + ...
    abs(z(f(bigtri,3))-z(f(bigtri,1))))/3;

SouthTriSide = (abs(w(f(inner,1))-w(f(inner,2))) + ...
    abs(w(f(inner,2))-w(f(inner,3))) + ...
    abs(w(f(inner,3))-w(f(inner,1))))/3;

z = z*(sqrt(NorthTriSide*SouthTriSide))/(NorthTriSide); % rescale to get the best distribution

vmap = [2*real(z)./(1+abs(z).^2), 2*imag(z)./(1+abs(z).^2), (-1+abs(z).^2)./(1+abs(z).^2)];

