function vmap = sphericalmap_modified(v,f,v_ori_new,M)
if nargin == 2
    v_ori_new = v;
end
%% Find most regular triangle
temp = v(reshape(f',1,length(f)*3),1:3);
e1 = sqrt(sum((temp(2:3:end,1:3) - temp(3:3:end,1:3))'.^2))';
e2 = sqrt(sum((temp(1:3:end,1:3) - temp(3:3:end,1:3))'.^2))';
e3 = sqrt(sum((temp(1:3:end,1:3) - temp(2:3:end,1:3))'.^2))';
regularity = abs(e1./(e1+e2+e3)-1/3)+...
    abs(e2./(e1+e2+e3)-1/3)+abs(e3./(e1+e2+e3)-1/3);
[~,bigtri] = min(regularity);

%% Map the mesh to big triangle
if nargin <4
    S = mesh2tri(v,f,bigtri); 
else
    S = mesh2tri(v,f,bigtri,M); 
end

if sum(sum(isnan(S))) ~= 0
    % use tutte map as the initial map
    S = spherical_tutte_map(f,bigtri);
end

%% 
[~,I] = sort(S(:,3));
% number of fixed points needed depends on mesh size
if length(v) < 500000
    fixnum = max(round(length(v)/50),3);
else
    % for stability, fix more points for dense mesh
    fixnum = max(round(length(v)/10),3);
end

fixed = I(1:min(length(v),fixnum)); 

P = [S(:,1)./(1+S(:,3)), S(:,2)./(1+S(:,3))];

%% South pole LBS
mu = bc_metric(P', f', v_ori_new', 3);
[map,~] = lbs(P',f',mu,fixed,P(fixed,1:2));

% if the result has NaN entries, then most probably the number of boundary constraints is not large enough
while sum(sum(isnan(map))) ~= 0
    % increase the number of boundary constrains and run again
    fixnum = fixnum*5;
    fixed = I(1:min(length(v),fixnum)); 
    [map,~] = lbs(P',f',mu,fixed,P(fixed,1:2)); 
end

z = complex(map(1,:),map(2,:))';

vmap = [2*real(z)./(1+abs(z).^2), 2*imag(z)./(1+abs(z).^2), -(abs(z).^2-1)./(1+abs(z).^2)];
